@@ -1,11 +1,11 @@
 /* $Id: tblock.h,v 1.2 1997/03/21 20:20:53 dps Exp $ */
 /* Dynamically grown text block */
 
+#include <string.h>
+
 #ifndef __tblock_h__
 #define __tblock_h__
 
-#include <strings.h>
-
 class tblock
 {
 private:
